// Copyright (c) 2013, the project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed 
// by a Apache license that can be found in the LICENSE file.

part of handheld;

/**
 * Describes the device's hardware and software.
 */
abstract class Device {
  /**
   * Access device accelerometer
   * 
   * See also [PhoneGap documentation for accelerometer](http://docs.phonegap.com/en/2.5.0/cordova_accelerometer_accelerometer.md.html)
   */
  DeviceAccelerometer get accelerometer;

  /**
   * Handler for visual, audible, and tactile device notifications.
   * 
   * See also [PhoneGap documentation for notifications](http://docs.phonegap.com/en/2.5.0/cordova_notification_notification.md.html)
   */
  DeviceNotification get notification;

  /**
   * Retrieve device information such as platform and version
   * 
   * See also [PhoneGap documentation for device](http://docs.phonegap.com/en/2.5.0/cordova_device_device.md.html)
   */
  DeviceInfo get info;

  /**
   * Returns a Database object for [name] and [version]. Where [displayname]
   * is a user friendly name required by the user agent and [size] is the
   * esitmated number of bytes required for the database.
   * 
   * See also [PhoneGap documentation for storage](http://docs.phonegap.com/en/2.5.0/cordova_storage_storage.md.html)
   */
  Future<DeviceDatabase> openDatabase(String name, String version, String displayname, int size);
}


