// Copyright (c) 2013, the project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed 
// by a Apache license that can be found in the LICENSE file.

part of handheld;

/** Device accelerometer */
abstract class DeviceAccelerometer {
  /** Get current acceleration */
  Future<DeviceAcceleration> get currentAcceleration;
  
  /**
   * Watch device acceleration. Returns a stream of acceleration events 
   * broadcasted at the specified milisecond [frequency]
   */
  DeviceAccelerationStream watchAcceleration(int frequency);
}

/** Device acceleration */
class DeviceAcceleration {
  DeviceAcceleration(this.x, this.y, this.z, this.timestamp);
  
  final num x, y, z;
  final DateTime timestamp;
}

/** Stream of [DeviceAcceleration] event's */
abstract class DeviceAccelerationStream {
  /**  Listen to [DeviceAcceleration] event's */
  listen(DeviceAccelerationListener listener);
  
  /** Close this stream */
  close();
}

/** Function executed when [DeviceAccelerationStream] retrieves a acceleration event */
typedef DeviceAccelerationListener(DeviceAcceleration acceleration);

