// Copyright (c) 2013, the project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed 
// by a Apache license that can be found in the LICENSE file.

library handheld_js_impl;

import 'dart:async';
import "dart:html" as html;

import "package:js/js.dart" as js;
import 'package:log4dart/log4dart.dart';
import 'package:meta/meta.dart';

import 'handheld_api.dart';

part 'js/device_js.dart';
part 'js/device_accelerometer_js.dart';
part 'js/device_notification_js.dart';

/*
 * TODO implement these functions.
 * Link to phonegap docs like in AWS
 * 
 * Camera
 *  - function onError(error) { console.log("error"); };
 *  - function onSuccess(position) { console.dir(position); };
 *   - navigator.camera.getPicture(onSuccess, onError, { quality: 50,
 *        destinationType: Camera.DestinationType.DATA_URL,
 *        sourceType: Camera.PictureSourceType.PHOTOLIBRARY
 *     }); 
 *   - where Camera.PictureSourceType and Camera.DestinationType are numeric enums
 * 
 * Position
 *  - navigator.geolocation.getCurrentPosition(onSuccess, onError);
 *  - function onError(error) { alert(error.message) };
 *  - function onSuccess(position) { console.dir(position); };
 * 
 * Network
 * - navigator.connection.type;
 * 
 * Notification
 * - navigator.notification.alert("hello");
 * - navigator.notification.beep(1); - TODO catch error on missing beep.wav
 */
class HandheldJs implements Handheld {
  factory HandheldJs() {
    if(_instance == null) {
      _instance = new HandheldJs._internal();
    }
    return _instance;
  }

  HandheldJs._internal();
  
  @override
  Future<Device> get onDeviceReady {
    if(_device != null) {
      // device already ready
      return new Future.value(_device);
    } else {
      // device not ready yet
      var deviceCompleter = new Completer<Device>();
      _device = new DeviceJs();
      _deviceReadyHandler(deviceCompleter, _device);
      return deviceCompleter.future; 
    }
  }
  
  _deviceReadyHandler(Completer<Device> completer, Device device) {
    js.scoped(() {
      js.context.handheldReady = new js.Callback.once(() {
        _logger.debug("handheld device ready");
        completer.complete(device);
      });
      // register global functions useful for development
      js.context.handheldReload = new js.Callback.many(() {
        html.queryAll("link").forEach((html.LinkElement elm) {
          if(elm.rel.toLowerCase().contains("stylesheet") && elm.href != null) {
            elm.href;
            var r = new RegExp(r"(&|\\?)forceReload=d ");
            var h = elm.href.replaceAll(r, "");
            elm.href = h + (h.indexOf('?')>=0 ? '&' : '?') + 'forceReload=' + (new DateTime.now().toString());
          }
        });
      });
      // TODO js.context.document.addEventListener("deviceready", callback, false);
    });
  }
  
  Device _device;
  static Handheld _instance;
  static final _logger = LoggerFactory.getLoggerFor(HandheldJs);
}

