// Copyright (c) 2013, the project authors. Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed 
// by a Apache license that can be found in the LICENSE file.

part of handheld_js_impl;

class DeviceAccelerometerJs implements DeviceAccelerometer {
  @override
  Future<DeviceAcceleration> get currentAcceleration {
    var completer = new Completer<DeviceAcceleration>();
    js.scoped(() {
      var onSuccess = new js.Callback.once((var acceleration) {
        var deviceAcceleration = _mapDeviceAcceleration(acceleration);
        completer.complete(deviceAcceleration);
      });
      var onError = new js.Callback.once(() {
        completer.completeError("getting device acceleration failed");
      });
      var notification = js.retain(js.context.navigator.notification);
      notification.beep(1);
      //js.context.navigator.accelerometer.getCurrentAcceleration(onSuccess, onError);
    });
    return completer.future;
  }
  
  @override
  DeviceAccelerationStream watchAcceleration(int frequency) => new JsDeviceAccelerationStream(frequency);
}

class JsDeviceAccelerationStream implements DeviceAccelerationStream  {
  JsDeviceAccelerationStream(int frequency) {
    js.scoped(() {
      var onSuccess = new js.Callback.many((var acceleration) {
        var deviceAcceleration = _mapDeviceAcceleration(acceleration);
        if(_listener != null) {
          _listener(deviceAcceleration);
        }
      });
      var onError = new js.Callback.once(() {
        throw "watching device acceleration failed";
      });
      var options = js.map({ 'frequency': frequency });
      _watchId = js.context.navigator.accelerometer.watchAcceleration(onSuccess, onError, options);
      //js.retain(_watchId);
    });
  }
  
  listen(DeviceAccelerationListener listener) => _listener = listener;
  
  close() {
    js.scoped(() {
      if(_watchId != null) {
        js.context.navigator.accelerometer.clearWatch(_watchId);
        //js.release(_watchId);
      }
    });
  }
  
  String _watchId;
  DeviceAccelerationListener _listener;
}

DeviceAcceleration _mapDeviceAcceleration(var acceleration) {
  var x = acceleration.x;
  var y = acceleration.y;
  var z = acceleration.z;
  var timestamp = acceleration.timestamp;
  // print("timestamp $timestamp");
  // TODO convert timestamp
  return new DeviceAcceleration(x,y,z, new DateTime.now());
}


